@@ -15,6 +15,12 @@ predict.C5.0 <- function (object, newdata = NULL, trials = object$trials["Actual
   if(length(trials) > 1) stop("only one value of trials is allowed")
   if(trials > object$trials["Actual"]) warning(paste("'trials' should be <=", object$trials["Actual"], "for this object. Predictions generated using", object$trials["Actual"], "trials"))
 
+  ## If there are case weights used during training, the C code will expect a 
+  ## column of rhtat in teh new data but the values will be ignored. `makeDataFile`
+  ## puts those last in teh data when `C5.0.default` is run, so we will add
+  ## a column of NA values at the end here
+  if(object$caseWeights) newdata$case_weight_pred <- NA
+  
   ## make cases file
   caseString <- makeDataFile(x = newdata, y = NULL)
   
@@ -22,7 +28,7 @@ predict.C5.0 <- function (object, newdata = NULL, trials = object$trials["Actual
   ##cat(caseString, '\n')
 
   ## When passing trials to the C code, convert to
-  ## zero if the original version of trails is used
+  ## zero if the original version of trials is used
 
   if(trials <= 0) stop("'trials should be a positive integer")
   if(trials == object$trials["Actual"]) trials <- 0
